@@ -35,7 +35,7 @@ class Act():
         except IOError:
             print 'Could not update, permission denied.'
             return
-        time.sleep(2)
+        time.sleep(5) #give the new port time to bind.
         self.get_uwsgi_port()
         return
 
